Tree

Struct Tree 

pub struct Tree { /* private fields */ }
A behavior tree framework for creating game AI structures.

Implementations

Source

impl Tree

pub fn seq(nodes: &Vec<Tree>) -> Tree

Creates a new sequence node that executes an array of child nodes in order.

Arguments
  • nodes - A vector of child nodes.
Returns
  • Leaf - A new sequence node.
pub fn sel(nodes: &Vec<Tree>) -> Tree

Creates a new selector node that selects and executes one of its child nodes that will succeed.

Arguments
  • nodes - A vector of child nodes.
Returns
  • Leaf - A new selector node.
pub fn con(name: &str, handler: Box<dyn FnMut(&Blackboard) -> bool>) -> Tree

Creates a new condition node that executes a check handler function when executed.

Arguments
  • name - The name of the condition.
  • check - A function that takes a blackboard object and returns a boolean value.
Returns
  • Leaf - A new condition node.
pub fn act(action_name: &str) -> Tree

Creates a new action node that executes an action when executed. This node will block the execution until the action finishes.

Arguments
  • action_name - The name of the action to execute.
Returns
  • Leaf - A new action node.
pub fn command(action_name: &str) -> Tree

Creates a new command node that executes a command when executed. This node will return right after the action starts.

Arguments
  • action_name - The name of the command to execute.
Returns
  • Leaf - A new command node.
pub fn wait(duration: f64) -> Tree

Creates a new wait node that waits for a specified duration when executed.

Arguments
  • duration - The duration to wait in seconds.
Returns
  • A new wait node of type Leaf.
pub fn countdown(time: f64, node: &Tree) -> Tree

Creates a new countdown node that executes a child node continuously until a timer runs out.

Arguments
  • time - The time limit in seconds.
  • node - The child node to execute.
Returns
  • A new countdown node of type Leaf.
pub fn timeout(time: f64, node: &Tree) -> Tree

Creates a new timeout node that executes a child node until a timer runs out.

Arguments
  • time - The time limit in seconds.
  • node - The child node to execute.
Returns
  • A new timeout node of type Leaf.
pub fn repeat(times: i32, node: &Tree) -> Tree

Creates a new repeat node that executes a child node a specified number of times.

Arguments
  • times - The number of times to execute the child node.
  • node - The child node to execute.
Returns
  • A new repeat node of type Leaf.
pub fn repeat_forever(node: &Tree) -> Tree

Creates a new repeat node that executes a child node repeatedly.

Arguments
  • node - The child node to execute.
Returns
  • A new repeat node of type Leaf.
pub fn retry(times: i32, node: &Tree) -> Tree

Creates a new retry node that executes a child node repeatedly until it succeeds or a maximum number of retries is reached.

Arguments
  • times - The maximum number of retries.
  • node - The child node to execute.
Returns
  • A new retry node of type Leaf.
pub fn retry_until_pass(node: &Tree) -> Tree

Creates a new retry node that executes a child node repeatedly until it succeeds.

Arguments
  • node - The child node to execute.
Returns
  • A new retry node of type Leaf.