Struct Tree

pub struct Tree { /* private fields */ }
A decision tree framework for creating game AI structures.

Implementations

Source

impl Tree

pub fn sel(nodes: &Vec<Tree>) -> Tree

Creates a selector node with the specified child nodes.

A selector node will go through the child nodes until one succeeds.

Arguments
  • nodes - An array of Leaf nodes.
Returns
  • A Leaf node that represents a selector.
pub fn seq(nodes: &Vec<Tree>) -> Tree

Creates a sequence node with the specified child nodes.

A sequence node will go through the child nodes until all nodes succeed.

Arguments
  • nodes - An array of Leaf nodes.
Returns
  • A Leaf node that represents a sequence.
pub fn con(name: &str, handler: Box<dyn FnMut(&Unit) -> bool>) -> Tree

Creates a condition node with the specified name and handler function.

Arguments
  • name - The name of the condition.
  • check - The check function that takes a Unit parameter and returns a boolean result.
Returns
  • A Leaf node that represents a condition check.
pub fn act(action_name: &str) -> Tree

Creates an action node with the specified action name.

Arguments
  • action_name - The name of the action to perform.
Returns
  • A Leaf node that represents an action.
pub fn act_dynamic(handler: Box<dyn FnMut(&Unit) -> String>) -> Tree

Creates an action node with the specified handler function.

Arguments
  • handler - The handler function that takes a Unit parameter which is the running AI agent and returns an action.
Returns
  • A Leaf node that represents an action.
pub fn accept() -> Tree

Creates a leaf node that represents accepting the current behavior tree.

Always get success result from this node.

Returns
  • A Leaf node.
pub fn reject() -> Tree

Creates a leaf node that represents rejecting the current behavior tree.

Always get failure result from this node.

Returns
  • A Leaf node.
pub fn behave(name: &str, root: &Tree) -> Tree

Creates a leaf node with the specified behavior tree as its root.

It is possible to include a Behavior Tree as a node in a Decision Tree by using the Behave() function. This allows the AI to use a combination of decision-making and behavior execution to achieve its goals.

Arguments
  • name - The name of the behavior tree.
  • root - The root node of the behavior tree.
Returns
  • A Leaf node.