Data

Struct Data 

pub struct Data {}
An interface that provides a centralized location for storing and accessing game-related data.

Implementations

Source

impl Data

pub fn get_group_first_player() -> i32

Gets the group key representing the first index for a player group.

pub fn get_group_last_player() -> i32

Gets the group key representing the last index for a player group.

pub fn get_group_hide() -> i32

Gets the group key that won’t have any contact with other groups by default.

pub fn get_group_detect_player() -> i32

Gets the group key that will have contacts with player groups by default.

pub fn get_group_terrain() -> i32

Gets the group key representing terrain that will have contacts with other groups by default.

pub fn get_group_detection() -> i32

Gets the group key that will have contacts with other groups by default.

pub fn get_store() -> Dictionary

Gets the dictionary that can be used to store arbitrary data associated with string keys and various values globally.

pub fn set_should_contact(group_a: i32, group_b: i32, contact: bool)

Sets a boolean value indicating whether two groups should be in contact or not.

Arguments
  • group_a - An integer representing the first group.
  • group_b - An integer representing the second group.
  • contact - A boolean indicating whether the two groups should be in contact.
pub fn get_should_contact(group_a: i32, group_b: i32) -> bool

Gets a boolean value indicating whether two groups should be in contact or not.

Arguments
  • group_a - An integer representing the first group.
  • group_b - An integer representing the second group.
Returns
  • A boolean indicating whether the two groups should be in contact.
pub fn set_relation(group_a: i32, group_b: i32, relation: Relation)

Sets the relation between two groups.

Arguments
  • group_a - An integer representing the first group.
  • group_b - An integer representing the second group.
  • relation - The relation between the two groups.
pub fn get_relation_by_group(group_a: i32, group_b: i32) -> Relation

Gets the relation between two groups.

Arguments
  • group_a - An integer representing the first group.
  • group_b - An integer representing the second group.
Returns
  • The relation between the two groups.
pub fn get_relation(body_a: &dyn IBody, body_b: &dyn IBody) -> Relation

A function that can be used to get the relation between two bodies.

Arguments
  • body_a - The first body.
  • body_b - The second body.
Returns
  • The relation between the two bodies.
pub fn is_enemy_group(group_a: i32, group_b: i32) -> bool

A function that returns whether two groups have an “Enemy” relation.

Arguments
  • group_a - An integer representing the first group.
  • group_b - An integer representing the second group.
Returns
  • A boolean indicating whether the two groups have an “Enemy” relation.
pub fn is_enemy(body_a: &dyn IBody, body_b: &dyn IBody) -> bool

A function that returns whether two bodies have an “Enemy” relation.

Arguments
  • body_a - The first body.
  • body_b - The second body.
Returns
  • A boolean indicating whether the two bodies have an “Enemy” relation.
pub fn is_friend_group(group_a: i32, group_b: i32) -> bool

A function that returns whether two groups have a “Friend” relation.

Arguments
  • group_a - An integer representing the first group.
  • group_b - An integer representing the second group.
Returns
  • A boolean indicating whether the two groups have a “Friend” relation.
pub fn is_friend(body_a: &dyn IBody, body_b: &dyn IBody) -> bool

A function that returns whether two bodies have a “Friend” relation.

Arguments
  • body_a - The first body.
  • body_b - The second body.
Returns
  • A boolean indicating whether the two bodies have a “Friend” relation.
pub fn is_neutral_group(group_a: i32, group_b: i32) -> bool

A function that returns whether two groups have a “Neutral” relation.

Arguments
  • group_a - An integer representing the first group.
  • group_b - An integer representing the second group.
Returns
  • A boolean indicating whether the two groups have a “Neutral” relation.
pub fn is_neutral(body_a: &dyn IBody, body_b: &dyn IBody) -> bool

A function that returns whether two bodies have a “Neutral” relation.

Arguments
  • body_a - The first body.
  • body_b - The second body.
Returns
  • A boolean indicating whether the two bodies have a “Neutral” relation.
pub fn set_damage_factor(damage_type: i32, defence_type: i32, bounus: f32)

Sets the bonus factor for a particular type of damage against a particular type of defence.

The builtin “MeleeAttack” and “RangeAttack” actions use a simple formula of finalDamage = damage * bonus.

Arguments
  • damage_type - An integer representing the type of damage.
  • defence_type - An integer representing the type of defence.
  • bonus - A number representing the bonus.
pub fn get_damage_factor(damage_type: i32, defence_type: i32) -> f32

Gets the bonus factor for a particular type of damage against a particular type of defence.

Arguments
  • damage_type - An integer representing the type of damage.
  • defence_type - An integer representing the type of defence.
Returns
  • A number representing the bonus factor.
pub fn is_player(body: &dyn IBody) -> bool

A function that returns whether a body is a player or not.

This works the same as Data::get_group_first_player() <= body.group and body.group <= Data::get_group_last_player().

Arguments
  • body - The body to check.
Returns
  • A boolean indicating whether the body is a player.
pub fn is_terrain(body: &dyn IBody) -> bool

A function that returns whether a body is terrain or not.

This works the same as body.group == Data::get_group_terrain().

Arguments
  • body - The body to check.
Returns
  • A boolean indicating whether the body is terrain.
pub fn clear()

Clears all data stored in the “Data” object, including user data in Data.store field. And reset some data to default values.