PlatformCamera

Struct PlatformCamera 

pub struct PlatformCamera { /* private fields */ }
A platform camera for 2D platformer games that can track a game unit’s movement and keep it within the camera’s view.

Implementations

Source

impl PlatformCamera

pub fn set_position(&mut self, val: &Vec2)

Sets The camera’s position.

pub fn get_position(&self) -> Vec2

Gets The camera’s position.

pub fn set_rotation(&mut self, val: f32)

Sets The camera’s rotation in degrees.

pub fn get_rotation(&self) -> f32

Gets The camera’s rotation in degrees.

pub fn set_zoom(&mut self, val: f32)

Sets The camera’s zoom factor, 1.0 means the normal size, 2.0 mean zoom to doubled size.

pub fn get_zoom(&self) -> f32

Gets The camera’s zoom factor, 1.0 means the normal size, 2.0 mean zoom to doubled size.

pub fn set_boundary(&mut self, val: &Rect)

Sets The rectangular area within which the camera is allowed to view.

pub fn get_boundary(&self) -> Rect

Gets The rectangular area within which the camera is allowed to view.

pub fn set_follow_ratio(&mut self, val: &Vec2)

Sets the ratio at which the camera should move to keep up with the target’s position. For example, set to Vec2(1.0, 1.0), then the camera will keep up to the target’s position right away. Set to Vec2(0.5, 0.5) or smaller value, then the camera will move halfway to the target’s position each frame, resulting in a smooth and gradual movement.

pub fn get_follow_ratio(&self) -> Vec2

Gets the ratio at which the camera should move to keep up with the target’s position. For example, set to Vec2(1.0, 1.0), then the camera will keep up to the target’s position right away. Set to Vec2(0.5, 0.5) or smaller value, then the camera will move halfway to the target’s position each frame, resulting in a smooth and gradual movement.

pub fn set_follow_offset(&mut self, val: &Vec2)

Sets the offset at which the camera should follow the target.

pub fn get_follow_offset(&self) -> Vec2

Gets the offset at which the camera should follow the target.

pub fn set_follow_target(&mut self, val: &dyn INode)

Sets the game unit that the camera should track.

pub fn get_follow_target(&self) -> Option<Node>

Gets the game unit that the camera should track.

pub fn set_follow_target_null(&mut self)

Removes the target that the camera is following.

pub fn new(name: &str) -> PlatformCamera

Creates a new instance of PlatformCamera.

Arguments
  • name - An optional string that specifies the name of the new instance. Default is an empty string.
Returns
  • A new PlatformCamera instance.