pub struct PlatformWorld { /* private fields */ }Expand description
A struct representing a 2D platformer game world with physics simulations.
Implementations
Sourceimpl PlatformWorld
impl PlatformWorld
Sourcepub fn get_camera(&self) -> PlatformCamera
pub fn get_camera(&self) -> PlatformCamera
Gets the camera used to control the view of the game world.
Sourcepub fn move_child(&mut self, child: &dyn INode, new_order: i32)
pub fn move_child(&mut self, child: &dyn INode, new_order: i32)
Moves a child node to a new order for a different layer.
Arguments
child- The child node to be moved.new_order- The new order of the child node.
Sourcepub fn set_layer_ratio(&mut self, order: i32, ratio: &Vec2)
pub fn set_layer_ratio(&mut self, order: i32, ratio: &Vec2)
Sets the parallax moving ratio for a given layer to simulate 3D projection effect.
Arguments
order- The order of the layer to set the ratio for.ratio- The new parallax ratio for the layer.
Sourcepub fn get_layer_ratio(&mut self, order: i32) -> Vec2
pub fn get_layer_ratio(&mut self, order: i32) -> Vec2
Sourcepub fn set_layer_offset(&mut self, order: i32, offset: &Vec2)
pub fn set_layer_offset(&mut self, order: i32, offset: &Vec2)
Sets the position offset for a given layer.
Arguments
order- The order of the layer to set the offset for.offset- AVec2representing the new position offset for the layer.
Sourcepub fn get_layer_offset(&mut self, order: i32) -> Vec2
pub fn get_layer_offset(&mut self, order: i32) -> Vec2
Sourcepub fn swap_layer(&mut self, order_a: i32, order_b: i32)
pub fn swap_layer(&mut self, order_a: i32, order_b: i32)
Swaps the positions of two layers.
Arguments
order_a- The order of the first layer to swap.order_b- The order of the second layer to swap.
Sourcepub fn remove_layer(&mut self, order: i32)
pub fn remove_layer(&mut self, order: i32)
Sourcepub fn remove_all_layers(&mut self)
pub fn remove_all_layers(&mut self)
Removes all layers from the game world.
Sourcepub fn new() -> PlatformWorld
pub fn new() -> PlatformWorld