TargetAllow

Struct TargetAllow 

pub struct TargetAllow { /* private fields */ }
A struct to specifies how a bullet object should interact with other game objects or units based on their relationship.

Implementations

Source

impl TargetAllow

pub fn set_terrain_allowed(&mut self, val: bool)

Sets whether the bullet object can collide with terrain.

pub fn is_terrain_allowed(&self) -> bool

Gets whether the bullet object can collide with terrain.

pub fn allow(&mut self, relation: Relation, allow: bool)

Allows or disallows the bullet object to interact with a game object or unit, based on their relationship.

Arguments
  • relation - The relationship between the bullet object and the other game object or unit.
  • allow - Whether the bullet object should be allowed to interact.
pub fn is_allow(&mut self, relation: Relation) -> bool

Determines whether the bullet object is allowed to interact with a game object or unit, based on their relationship.

Arguments
  • relation - The relationship between the bullet object and the other game object or unit.
Returns
  • bool - Whether the bullet object is allowed to interact.
pub fn to_value(&mut self) -> i32

Converts the object to a value that can be used for interaction settings.

Returns
  • usize - The value that can be used for interaction settings.
pub fn new() -> TargetAllow

Creates a new TargetAllow object with default settings.

pub fn with_value(value: i32) -> TargetAllow

Creates a new TargetAllow object with the specified value.

Arguments
  • value - The value to use for the new TargetAllow object.