ActionDef

Struct ActionDef 

pub struct ActionDef { /* private fields */ }

Implementations

Source

impl ActionDef

pub fn prop( duration: f32, start: f32, stop: f32, prop: Property, easing: EaseType, ) -> ActionDef

Creates a new action definition object to change a property of a node.

Arguments
  • duration - The duration of the action.
  • start - The starting value of the property.
  • stop - The ending value of the property.
  • prop - The property to change.
  • easing - The easing function to use.
Returns
  • ActionDef - A new ActionDef object.
pub fn tint( duration: f32, start: &Color3, stop: &Color3, easing: EaseType, ) -> ActionDef

Creates a new action definition object to change the color of a node.

Arguments
  • duration - The duration of the action.
  • start - The starting color.
  • stop - The ending color.
  • easing - The easing function to use.
Returns
  • ActionDef - A new ActionDef object.
pub fn roll(duration: f32, start: f32, stop: f32, easing: EaseType) -> ActionDef

Creates a new action definition object to rotate a node by smallest angle.

Arguments
  • duration - The duration of the action.
  • start - The starting angle.
  • stop - The ending angle.
  • easing - The easing function to use.
Returns
  • ActionDef - A new ActionDef object.
pub fn spawn(defs: &Vec<ActionDef>) -> ActionDef

Creates a new action definition object to run a group of actions in parallel.

Arguments
  • defs - The actions to run in parallel.
Returns
  • ActionDef - A new ActionDef object.
pub fn sequence(defs: &Vec<ActionDef>) -> ActionDef

Creates a new action definition object to run a group of actions in sequence.

Arguments
  • defs - The actions to run in sequence.
Returns
  • ActionDef - A new ActionDef object.
pub fn delay(duration: f32) -> ActionDef

Creates a new action definition object to delay the execution of following action.

Arguments
  • duration - The duration of the delay.
Returns
  • ActionDef - A new ActionDef object.
pub fn show() -> ActionDef

Creates a new action definition object to show a node.

pub fn hide() -> ActionDef

Creates a new action definition object to hide a node.

pub fn event(event_name: &str, msg: &str) -> ActionDef

Creates a new action definition object to emit an event.

Arguments
  • eventName - The name of the event to emit.
  • msg - The message to send with the event.
Returns
  • ActionDef - A new ActionDef object.
pub fn move_to( duration: f32, start: &Vec2, stop: &Vec2, easing: EaseType, ) -> ActionDef

Creates a new action definition object to move a node.

Arguments
  • duration - The duration of the action.
  • start - The starting position.
  • stop - The ending position.
  • easing - The easing function to use.
Returns
  • ActionDef - A new ActionDef object.
pub fn scale( duration: f32, start: f32, stop: f32, easing: EaseType, ) -> ActionDef

Creates a new action definition object to scale a node.

Arguments
  • duration - The duration of the action.
  • start - The starting scale.
  • stop - The ending scale.
  • easing - The easing function to use.
Returns
  • ActionDef - A new ActionDef object.
pub fn frame(clip_str: &str, duration: f32) -> ActionDef

Creates a new action definition object to do a frame animation. Can only be performed on a Sprite node.

Arguments
  • clipStr - The name of the image clip, which is a sprite sheet. Can be “Image/file.png” and “Image/items.clip|itemA”. Supports image file format: jpg, png, dds, pvr, ktx.
  • duration - The duration of the action.
Returns
  • ActionDef - A new ActionDef object.
pub fn frame_with_frames( clip_str: &str, duration: f32, frames: &Vec<i32>, ) -> ActionDef

Creates a new action definition object to do a frame animation with frames count for each frame. Can only be performed on a Sprite node.

Arguments
  • clipStr - The name of the image clip, which is a sprite sheet. Can be “Image/file.png” and “Image/items.clip|itemA”. Supports image file format: jpg, png, dds, pvr, ktx.
  • duration - The duration of the action.
  • frames - The number of frames for each frame.
Returns
  • Action - A new Action object.