Struct Audio

pub struct Audio {}
A interface of an audio player.

Implementations

Source

impl Audio

pub fn play(filename: &str, looping: bool) -> i32

Plays a sound effect and returns a handler for the audio.

Arguments
  • filename - The path to the sound effect file (must be a WAV file).
  • loop - Optional. Whether to loop the sound effect. Default is false.
Returns
  • i32 - A handler for the audio that can be used to stop the sound effect.
pub fn stop(handle: i32)

Stops a sound effect that is currently playing.

Arguments
  • handler - The handler for the audio that is returned by the play function.
pub fn play_stream(filename: &str, looping: bool, cross_fade_time: f32)

Plays a streaming audio file.

Arguments
  • filename - The path to the streaming audio file (can be OGG, WAV, MP3, or FLAC).
  • loop - Whether to loop the streaming audio.
  • crossFadeTime - The time (in seconds) to crossfade between the previous and new streaming audio.
pub fn stop_stream(fade_time: f32)

Stops a streaming audio file that is currently playing.

Arguments
  • fade_time - The time (in seconds) to fade out the streaming audio.