pub struct CameraOtho { /* private fields */ }Expand description
A struct for an orthographic camera object in the game engine.
Implementations
Sourceimpl CameraOtho
impl CameraOtho
Sourcepub fn set_position(&mut self, val: &Vec2)
pub fn set_position(&mut self, val: &Vec2)
Sets the position of the camera in the game world.
Sourcepub fn get_position(&self) -> Vec2
pub fn get_position(&self) -> Vec2
Gets the position of the camera in the game world.