pub struct Effect { /* private fields */ }Expand description
A struct for managing multiple render pass objects. Effect objects allow you to combine multiple passes to create more complex shader effects.
Implementations
Sourceimpl Effect
impl Effect
Sourcepub fn new(vert_shader: &str, frag_shader: &str) -> Effect
pub fn new(vert_shader: &str, frag_shader: &str) -> Effect
A method that allows you to create a new Effect object.
Arguments
vert_shader- The vertex shader file string.frag_shader- The fragment shader file string. A shader file string must be one of the formats:- “builtin:” + theBuiltinShaderName
- “Shader/compiled_shader_file.bin”
Returns
Effect- A new Effect object.