pub struct MotorJoint { /* private fields */ }Expand description
A joint that applies a rotational or linear force to a physics body.
Implementations
Sourceimpl MotorJoint
impl MotorJoint
Sourcepub fn set_enabled(&mut self, val: bool)
pub fn set_enabled(&mut self, val: bool)
Sets whether or not the motor joint is enabled.
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Gets whether or not the motor joint is enabled.