Struct PhysicsWorld

pub struct PhysicsWorld { /* private fields */ }
A struct that represents a physics world in the game.

Implementations

Source

impl PhysicsWorld

pub fn set_scale_factor(val: f32)

Sets the factor used for converting physics engine meters value to pixel value. Default 100.0 is a good value since the physics engine can well simulate real life objects between 0.1 to 10 meters. Use value 100.0 we can simulate game objects between 10 to 1000 pixels that suite most games. You can change this value before any physics body creation.

pub fn get_scale_factor() -> f32

Gets the factor used for converting physics engine meters value to pixel value. Default 100.0 is a good value since the physics engine can well simulate real life objects between 0.1 to 10 meters. Use value 100.0 we can simulate game objects between 10 to 1000 pixels that suite most games. You can change this value before any physics body creation.

pub fn new() -> PhysicsWorld

Creates a new PhysicsWorld object.

Returns
  • A new PhysicsWorld object.
Source

impl PhysicsWorld

pub fn cast(obj: &dyn IObject) -> Option<PhysicsWorld>

Casts the object to a physics world.

Arguments
  • obj - The object to cast.
Returns
  • Option<PhysicsWorld> - The physics world if the object is a physics world, None otherwise.