Struct Scheduler

pub struct Scheduler { /* private fields */ }
A scheduler that manages the execution of scheduled tasks.

Implementations

Source

impl Scheduler

pub fn set_time_scale(&mut self, val: f32)

Sets the time scale factor for the scheduler. This factor is applied to deltaTime that the scheduled functions will receive.

pub fn get_time_scale(&self) -> f32

Gets the time scale factor for the scheduler. This factor is applied to deltaTime that the scheduled functions will receive.

pub fn set_fixed_fps(&mut self, val: i32)

Sets the target frame rate (in frames per second) for a fixed update mode. The fixed update will ensure a constant frame rate, and the operation handled in a fixed update can use a constant delta time value. It is used for preventing weird behavior of a physics engine or synchronizing some states via network communications.

pub fn get_fixed_fps(&self) -> i32

Gets the target frame rate (in frames per second) for a fixed update mode. The fixed update will ensure a constant frame rate, and the operation handled in a fixed update can use a constant delta time value. It is used for preventing weird behavior of a physics engine or synchronizing some states via network communications.

pub fn update(&mut self, delta_time: f64) -> bool

Used for manually updating the scheduler if it is created by the user.

Arguments
  • deltaTime - The time in seconds since the last frame update.
Returns
  • bool - true if the scheduler was stoped, false otherwise.
pub fn new() -> Scheduler

Creates a new Scheduler object.