pub struct TileNode { /* private fields */ }Expand description
The TileNode class to render Tilemaps from TMX file in game scene tree hierarchy.
Implementations
Sourceimpl TileNode
impl TileNode
Sourcepub fn set_depth_write(&mut self, val: bool)
pub fn set_depth_write(&mut self, val: bool)
Sets whether the depth buffer should be written to when rendering the tilemap.
Sourcepub fn is_depth_write(&self) -> bool
pub fn is_depth_write(&self) -> bool
Gets whether the depth buffer should be written to when rendering the tilemap.
Sourcepub fn set_blend_func(&mut self, val: BlendFunc)
pub fn set_blend_func(&mut self, val: BlendFunc)
Sets the blend function for the tilemap.
Sourcepub fn get_blend_func(&self) -> BlendFunc
pub fn get_blend_func(&self) -> BlendFunc
Gets the blend function for the tilemap.
Sourcepub fn set_effect(&mut self, val: &SpriteEffect)
pub fn set_effect(&mut self, val: &SpriteEffect)
Sets the tilemap shader effect.
Sourcepub fn get_effect(&self) -> SpriteEffect
pub fn get_effect(&self) -> SpriteEffect
Gets the tilemap shader effect.
Sourcepub fn set_filter(&mut self, val: TextureFilter)
pub fn set_filter(&mut self, val: TextureFilter)
Sets the texture filtering mode for the tilemap.
Sourcepub fn get_filter(&self) -> TextureFilter
pub fn get_filter(&self) -> TextureFilter
Gets the texture filtering mode for the tilemap.
Sourcepub fn get_layer(&self, layer_name: &str) -> Option<Dictionary>
pub fn get_layer(&self, layer_name: &str) -> Option<Dictionary>
Sourcepub fn new(tmx_file: &str) -> Option<TileNode>
pub fn new(tmx_file: &str) -> Option<TileNode>
Creates a TileNode object that will render the tile layers from a TMX file.
Arguments
tmxFile- The TMX file for the tilemap. This should be a file created with the Tiled Map Editor (http://www.mapeditor.org) and must be in XML format.
Returns
Returns a new instance of the TileNode class. If the tilemap file is not found, it will return None.
Sourcepub fn with_with_layer(tmx_file: &str, layer_name: &str) -> Option<TileNode>
pub fn with_with_layer(tmx_file: &str, layer_name: &str) -> Option<TileNode>
Creates a TileNode object that will render the specified tile layer from a TMX file.
Arguments
tmxFile- The TMX file for the tilemap. This should be a file created with the Tiled Map Editor (http://www.mapeditor.org) and must be in XML format.layerName- The name of the layer in the TMX file.
Returns
Returns a new instance of the TileNode class. If the tilemap file is not found, it will return None.
Sourcepub fn with_with_layers(
tmx_file: &str,
layer_names: &Vec<&str>,
) -> Option<TileNode>
pub fn with_with_layers( tmx_file: &str, layer_names: &Vec<&str>, ) -> Option<TileNode>
Creates a TileNode object that will render the specified tile layers from a TMX file.
Arguments
tmxFile- The TMX file for the tilemap. This should be a file created with the Tiled Map Editor (http://www.mapeditor.org) and must be in XML format.layerNames- A vector of names of the layers in the TMX file.
Returns
Returns a new instance of the TileNode class. If the tilemap file is not found, it will return None.