pub struct Touch { /* private fields */ }Expand description
Represents a touch input or mouse click event.
Implementations
Sourceimpl Touch
impl Touch
Sourcepub fn set_enabled(&mut self, val: bool)
pub fn set_enabled(&mut self, val: bool)
Sets whether touch input is enabled or not.
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Gets whether touch input is enabled or not.
Sourcepub fn is_first(&self) -> bool
pub fn is_first(&self) -> bool
Gets whether this is the first touch event when multi-touches exist.
Sourcepub fn get_delta(&self) -> Vec2
pub fn get_delta(&self) -> Vec2
Gets the amount and direction of movement since the last touch event.
Sourcepub fn get_location(&self) -> Vec2
pub fn get_location(&self) -> Vec2
Gets the location of the touch event in the node’s local coordinate system.
Sourcepub fn get_world_location(&self) -> Vec2
pub fn get_world_location(&self) -> Vec2
Gets the location of the touch event in the world coordinate system.