Struct View

pub struct View {}
A struct that provides access to the 3D graphic view.

Implementations

Source

impl View

pub fn get_size() -> Size

Gets the size of the view in pixels.

pub fn get_standard_distance() -> f32

Gets the standard distance of the view from the origin.

pub fn get_aspect_ratio() -> f32

Gets the aspect ratio of the view.

pub fn set_near_plane_distance(val: f32)

Sets the distance to the near clipping plane.

pub fn get_near_plane_distance() -> f32

Gets the distance to the near clipping plane.

pub fn set_far_plane_distance(val: f32)

Sets the distance to the far clipping plane.

pub fn get_far_plane_distance() -> f32

Gets the distance to the far clipping plane.

pub fn set_field_of_view(val: f32)

Sets the field of view of the view in degrees.

pub fn get_field_of_view() -> f32

Gets the field of view of the view in degrees.

pub fn set_scale(val: f32)

Sets the scale factor of the view.

pub fn get_scale() -> f32

Gets the scale factor of the view.

pub fn set_post_effect(val: &SpriteEffect)

Sets the post effect applied to the view.

pub fn get_post_effect() -> Option<SpriteEffect>

Gets the post effect applied to the view.

pub fn set_post_effect_null()

Removes the post effect applied to the view.

pub fn set_vsync(val: bool)

Sets whether or not vertical sync is enabled.

pub fn is_vsync() -> bool

Gets whether or not vertical sync is enabled.