pub struct Tree { /* private fields */ }Expand description
A decision tree framework for creating game AI structures.
Implementations
Sourceimpl Tree
impl Tree
Sourcepub fn accept() -> Tree
pub fn accept() -> Tree
Creates a leaf node that represents accepting the current behavior tree.
Always get success result from this node.
Returns
- A
Leafnode.
Sourcepub fn reject() -> Tree
pub fn reject() -> Tree
Creates a leaf node that represents rejecting the current behavior tree.
Always get failure result from this node.
Returns
- A
Leafnode.
Sourcepub fn behave(name: &str, root: &Tree) -> Tree
pub fn behave(name: &str, root: &Tree) -> Tree
Creates a leaf node with the specified behavior tree as its root.
It is possible to include a Behavior Tree as a node in a Decision Tree by using the Behave() function. This allows the AI to use a combination of decision-making and behavior execution to achieve its goals.
Arguments
name- The name of the behavior tree.root- The root node of the behavior tree.
Returns
- A
Leafnode.