pub struct Unit { /* private fields */ }Expand description
A struct represents a character or other interactive item in a game scene.
Implementations
Sourceimpl Unit
impl Unit
Sourcepub fn set_playable(&mut self, val: &dyn IPlayable)
pub fn set_playable(&mut self, val: &dyn IPlayable)
Sets the property that references a “Playable” object for managing the animation state and playback of the “Unit”.
Sourcepub fn get_playable(&self) -> Playable
pub fn get_playable(&self) -> Playable
Gets the property that references a “Playable” object for managing the animation state and playback of the “Unit”.
Sourcepub fn set_detect_distance(&mut self, val: f32)
pub fn set_detect_distance(&mut self, val: f32)
Sets the property that specifies the maximum distance at which the “Unit” can detect other “Unit” or objects.
Sourcepub fn get_detect_distance(&self) -> f32
pub fn get_detect_distance(&self) -> f32
Gets the property that specifies the maximum distance at which the “Unit” can detect other “Unit” or objects.
Sourcepub fn set_attack_range(&mut self, val: &Size)
pub fn set_attack_range(&mut self, val: &Size)
Sets the property that specifies the size of the attack range for the “Unit”.
Sourcepub fn get_attack_range(&self) -> Size
pub fn get_attack_range(&self) -> Size
Gets the property that specifies the size of the attack range for the “Unit”.
Sourcepub fn set_face_right(&mut self, val: bool)
pub fn set_face_right(&mut self, val: bool)
Sets the boolean property that specifies whether the “Unit” is facing right or not.
Sourcepub fn is_face_right(&self) -> bool
pub fn is_face_right(&self) -> bool
Gets the boolean property that specifies whether the “Unit” is facing right or not.
Sourcepub fn set_receiving_decision_trace(&mut self, val: bool)
pub fn set_receiving_decision_trace(&mut self, val: bool)
Sets the boolean property that specifies whether the “Unit” is receiving a trace of the decision tree for debugging purposes.
Sourcepub fn is_receiving_decision_trace(&self) -> bool
pub fn is_receiving_decision_trace(&self) -> bool
Gets the boolean property that specifies whether the “Unit” is receiving a trace of the decision tree for debugging purposes.
Sourcepub fn set_decision_tree(&mut self, val: &str)
pub fn set_decision_tree(&mut self, val: &str)
Sets the string property that specifies the decision tree to use for the “Unit’s” AI behavior. the decision tree object will be searched in The singleton instance Data.store.
Sourcepub fn get_decision_tree(&self) -> String
pub fn get_decision_tree(&self) -> String
Gets the string property that specifies the decision tree to use for the “Unit’s” AI behavior. the decision tree object will be searched in The singleton instance Data.store.
Sourcepub fn is_on_surface(&self) -> bool
pub fn is_on_surface(&self) -> bool
Gets whether the “Unit” is currently on a surface or not.
Sourcepub fn get_ground_sensor(&self) -> Sensor
pub fn get_ground_sensor(&self) -> Sensor
Gets the “Sensor” object for detecting ground surfaces.
Sourcepub fn get_detect_sensor(&self) -> Sensor
pub fn get_detect_sensor(&self) -> Sensor
Gets the “Sensor” object for detecting other “Unit” objects or physics bodies in the game world.
Sourcepub fn get_attack_sensor(&self) -> Sensor
pub fn get_attack_sensor(&self) -> Sensor
Gets the “Sensor” object for detecting other “Unit” objects within the attack senser area.
Sourcepub fn get_unit_def(&self) -> Dictionary
pub fn get_unit_def(&self) -> Dictionary
Gets the “Dictionary” object for defining the properties and behavior of the “Unit”.
Sourcepub fn get_current_action(&self) -> UnitAction
pub fn get_current_action(&self) -> UnitAction
Gets the property that specifies the current action being performed by the “Unit”.
Sourcepub fn get_height(&self) -> f32
pub fn get_height(&self) -> f32
Gets the height of the “Unit”.
Sourcepub fn get_entity(&self) -> Entity
pub fn get_entity(&self) -> Entity
Gets the “Entity” object for representing the “Unit” in the ECS system.
Sourcepub fn attach_action(&mut self, name: &str) -> UnitAction
pub fn attach_action(&mut self, name: &str) -> UnitAction
Sourcepub fn remove_action(&mut self, name: &str)
pub fn remove_action(&mut self, name: &str)
Removes the UnitAction with the specified name from the Unit.
Arguments
name- The name of theUnitActionto remove.
Sourcepub fn remove_all_actions(&mut self)
pub fn remove_all_actions(&mut self)
Removes all “UnitAction” objects from the “Unit”.
Sourcepub fn get_action(&mut self, name: &str) -> Option<UnitAction>
pub fn get_action(&mut self, name: &str) -> Option<UnitAction>
Sourcepub fn each_action(&mut self, visitor_func: Box<dyn FnMut(&UnitAction)>)
pub fn each_action(&mut self, visitor_func: Box<dyn FnMut(&UnitAction)>)
Calls the specified function for each UnitAction attached to the Unit.
Arguments
visitorFunc- A function to call for eachUnitAction.
Sourcepub fn new(
unit_def: &Dictionary,
physics_world: &dyn IPhysicsWorld,
entity: &Entity,
pos: &Vec2,
rot: f32,
) -> Unit
pub fn new( unit_def: &Dictionary, physics_world: &dyn IPhysicsWorld, entity: &Entity, pos: &Vec2, rot: f32, ) -> Unit
A method that creates a new Unit object.
Arguments
unit_def- ADictionaryobject that defines the properties and behavior of theUnit.physics_world- APhysicsWorldobject that represents the physics simulation world.entity- AnEntityobject that represents theUnitin ECS system.pos- AVec2object that specifies the initial position of theUnit.rot- A number that specifies the initial rotation of theUnit.
Returns
- The newly created
Unitobject.
Sourcepub fn with_store(
unit_def_name: &str,
physics_world_name: &str,
entity: &Entity,
pos: &Vec2,
rot: f32,
) -> Unit
pub fn with_store( unit_def_name: &str, physics_world_name: &str, entity: &Entity, pos: &Vec2, rot: f32, ) -> Unit
A method that creates a new Unit object.
Arguments
unit_def_name- A string that specifies the name of theUnitdefinition to retrieve fromData.storetable.physics_world_name- A string that specifies the name of thePhysicsWorldobject to retrieve fromData.storetable.entity- AnEntityobject that represents theUnitin ECS system.pos- AVec2object that specifies the initial position of theUnit.rot- An optional number that specifies the initial rotation of theUnit(default is 0.0).
Returns
- The newly created
Unitobject.