pub struct Audio {}Expand description
A interface of an audio player.
Implementations
Sourceimpl Audio
impl Audio
Sourcepub fn stop(handle: i32)
pub fn stop(handle: i32)
Stops a sound effect that is currently playing.
Arguments
handler- The handler for the audio that is returned by theplayfunction.
Sourcepub fn play_stream(filename: &str, looping: bool, cross_fade_time: f32)
pub fn play_stream(filename: &str, looping: bool, cross_fade_time: f32)
Plays a streaming audio file.
Arguments
filename- The path to the streaming audio file (can be OGG, WAV, MP3, or FLAC).loop- Whether to loop the streaming audio.crossFadeTime- The time (in seconds) to crossfade between the previous and new streaming audio.
Sourcepub fn stop_stream(fade_time: f32)
pub fn stop_stream(fade_time: f32)
Stops a streaming audio file that is currently playing.
Arguments
fade_time- The time (in seconds) to fade out the streaming audio.