pub struct View {}Expand description
A struct that provides access to the 3D graphic view.
Implementations
Sourceimpl View
impl View
Sourcepub fn get_standard_distance() -> f32
pub fn get_standard_distance() -> f32
Gets the standard distance of the view from the origin.
Sourcepub fn get_aspect_ratio() -> f32
pub fn get_aspect_ratio() -> f32
Gets the aspect ratio of the view.
Sourcepub fn set_near_plane_distance(val: f32)
pub fn set_near_plane_distance(val: f32)
Sets the distance to the near clipping plane.
Sourcepub fn get_near_plane_distance() -> f32
pub fn get_near_plane_distance() -> f32
Gets the distance to the near clipping plane.
Sourcepub fn set_far_plane_distance(val: f32)
pub fn set_far_plane_distance(val: f32)
Sets the distance to the far clipping plane.
Sourcepub fn get_far_plane_distance() -> f32
pub fn get_far_plane_distance() -> f32
Gets the distance to the far clipping plane.
Sourcepub fn set_field_of_view(val: f32)
pub fn set_field_of_view(val: f32)
Sets the field of view of the view in degrees.
Sourcepub fn get_field_of_view() -> f32
pub fn get_field_of_view() -> f32
Gets the field of view of the view in degrees.
Sourcepub fn set_post_effect(val: &SpriteEffect)
pub fn set_post_effect(val: &SpriteEffect)
Sets the post effect applied to the view.
Sourcepub fn get_post_effect() -> Option<SpriteEffect>
pub fn get_post_effect() -> Option<SpriteEffect>
Gets the post effect applied to the view.
Sourcepub fn set_post_effect_null()
pub fn set_post_effect_null()
Removes the post effect applied to the view.